@@ -28,33 +28,27 @@
 *****************************************************************************
 * Contents: Native high-level C interface to LAPACK function csyconv
 * Author: Intel Corporation
-* Generated November 2015
 *****************************************************************************/
 
 #include "lapacke_utils.h"
 
-lapack_int LAPACKE_csyconv( int matrix_layout, char uplo, char way, lapack_int n,
+lapack_int API_SUFFIX(LAPACKE_csyconv)( int matrix_layout, char uplo, char way, lapack_int n,
                             lapack_complex_float* a, lapack_int lda,
                             const lapack_int* ipiv,
                             lapack_complex_float* e )
 {
-    lapack_int info = 0;
     if( matrix_layout != LAPACK_COL_MAJOR && matrix_layout != LAPACK_ROW_MAJOR ) {
-        LAPACKE_xerbla( "LAPACKE_csyconv", -1 );
+        API_SUFFIX(LAPACKE_xerbla)( "LAPACKE_csyconv", -1 );
         return -1;
     }
 #ifndef LAPACK_DISABLE_NAN_CHECK
-    /* Optionally check input matrices for NaNs */
-    if( LAPACKE_cge_nancheck( matrix_layout, n, n, a, lda ) ) {
-        return -5;
+    if( LAPACKE_get_nancheck() ) {
+        /* Optionally check input matrices for NaNs */
+        if( API_SUFFIX(LAPACKE_csy_nancheck)( matrix_layout, uplo, n, a, lda ) ) {
+            return -5;
+        }
     }
 #endif
     /* Call middle-level interface */
-    info = LAPACKE_csyconv_work( matrix_layout, uplo, way, n, a, lda, ipiv,
-                                 e );
-exit_level_0:
-    if( info == LAPACK_WORK_MEMORY_ERROR ) {
-        LAPACKE_xerbla( "LAPACKE_csyconv", info );
-    }
-    return info;
+    return API_SUFFIX(LAPACKE_csyconv_work)( matrix_layout, uplo, way, n, a, lda, ipiv, e );
 }
