@@ -28,12 +28,11 @@
 *****************************************************************************
 * Contents: Native middle-level C interface to LAPACK function csyswapr
 * Author: Intel Corporation
-* Generated November 2015
 *****************************************************************************/
 
 #include "lapacke_utils.h"
 
-lapack_int LAPACKE_csyswapr_work( int matrix_layout, char uplo, lapack_int n,
+lapack_int API_SUFFIX(LAPACKE_csyswapr_work)( int matrix_layout, char uplo, lapack_int n,
                                   lapack_complex_float* a, lapack_int lda,
                                   lapack_int i1, lapack_int i2 )
 {
@@ -55,21 +54,21 @@ lapack_int LAPACKE_csyswapr_work( int matrix_layout, char uplo, lapack_int n,
             goto exit_level_0;
         }
         /* Transpose input matrices */
-        LAPACKE_csy_trans( matrix_layout, uplo, n, a, lda, a_t, lda_t );
+        API_SUFFIX(LAPACKE_csy_trans)( matrix_layout, uplo, n, a, lda, a_t, lda_t );
         /* Call LAPACK function and adjust info */
         LAPACK_csyswapr( &uplo, &n, a_t, &lda_t, &i1, &i2 );
         info = 0;  /* LAPACK call is ok! */
         /* Transpose output matrices */
-        LAPACKE_csy_trans( LAPACK_COL_MAJOR, uplo, n, a_t, lda_t, a, lda );
+        API_SUFFIX(LAPACKE_csy_trans)( LAPACK_COL_MAJOR, uplo, n, a_t, lda_t, a, lda );
         /* Release memory and exit */
         LAPACKE_free( a_t );
 exit_level_0:
         if( info == LAPACK_TRANSPOSE_MEMORY_ERROR ) {
-            LAPACKE_xerbla( "LAPACKE_csyswapr_work", info );
+            API_SUFFIX(LAPACKE_xerbla)( "LAPACKE_csyswapr_work", info );
         }
     } else {
         info = -1;
-        LAPACKE_xerbla( "LAPACKE_csyswapr_work", info );
+        API_SUFFIX(LAPACKE_xerbla)( "LAPACKE_csyswapr_work", info );
     }
     return info;
 }
