@@ -28,12 +28,11 @@
 *****************************************************************************
 * Contents: Native middle-level C interface to LAPACK function dsyconv
 * Author: Intel Corporation
-* Generated November 2015
 *****************************************************************************/
 
 #include "lapacke_utils.h"
 
-lapack_int LAPACKE_dsyconv_work( int matrix_layout, char uplo, char way,
+lapack_int API_SUFFIX(LAPACKE_dsyconv_work)( int matrix_layout, char uplo, char way,
                                  lapack_int n, double* a, lapack_int lda,
                                  const lapack_int* ipiv, double* e )
 {
@@ -50,7 +49,7 @@ lapack_int LAPACKE_dsyconv_work( int matrix_layout, char uplo, char way,
         /* Check leading dimension(s) */
         if( lda < n ) {
             info = -6;
-            LAPACKE_xerbla( "LAPACKE_dsyconv_work", info );
+            API_SUFFIX(LAPACKE_xerbla)( "LAPACKE_dsyconv_work", info );
             return info;
         }
         /* Allocate memory for temporary array(s) */
@@ -60,23 +59,23 @@ lapack_int LAPACKE_dsyconv_work( int matrix_layout, char uplo, char way,
             goto exit_level_0;
         }
         /* Transpose input matrices */
-        LAPACKE_dge_trans( matrix_layout, lda, n, a, lda, a_t, lda_t );
+        API_SUFFIX(LAPACKE_dge_trans)( matrix_layout, lda, n, a, lda, a_t, lda_t );
         /* Call LAPACK function and adjust info */
         LAPACK_dsyconv( &uplo, &way, &n, a_t, &lda_t, ipiv, e, &info );
         if( info < 0 ) {
             info = info - 1;
         }
         /* Transpose output matrices */
-        LAPACKE_dge_trans( LAPACK_COL_MAJOR, lda, n, a_t, lda_t, a, lda );
+        API_SUFFIX(LAPACKE_dge_trans)( LAPACK_COL_MAJOR, lda, n, a_t, lda_t, a, lda );
         /* Release memory and exit */
         LAPACKE_free( a_t );
 exit_level_0:
         if( info == LAPACK_TRANSPOSE_MEMORY_ERROR ) {
-            LAPACKE_xerbla( "LAPACKE_dsyconv_work", info );
+            API_SUFFIX(LAPACKE_xerbla)( "LAPACKE_dsyconv_work", info );
         }
     } else {
         info = -1;
-        LAPACKE_xerbla( "LAPACKE_dsyconv_work", info );
+        API_SUFFIX(LAPACKE_xerbla)( "LAPACKE_dsyconv_work", info );
     }
     return info;
 }
