@@ -28,12 +28,11 @@
 *****************************************************************************
 * Contents: Native high-level C interface to LAPACK function zuncsd2by1
 * Author: Intel Corporation
-* Generated November 2015
 *****************************************************************************/
 
 #include "lapacke_utils.h"
 
-lapack_int LAPACKE_zuncsd2by1( int matrix_layout, char jobu1, char jobu2,
+lapack_int API_SUFFIX(LAPACKE_zuncsd2by1)( int matrix_layout, char jobu1, char jobu2,
                            char jobv1t, lapack_int m, lapack_int p, lapack_int q,
                            lapack_complex_double* x11, lapack_int ldx11,
                            lapack_complex_double* x21, lapack_int ldx21,
@@ -51,21 +50,22 @@ lapack_int LAPACKE_zuncsd2by1( int matrix_layout, char jobu1, char jobu2,
     lapack_complex_double work_query;
     lapack_int nrows_x11, nrows_x21;
     if( matrix_layout != LAPACK_COL_MAJOR && matrix_layout != LAPACK_ROW_MAJOR ) {
-        LAPACKE_xerbla( "LAPACKE_zuncsd2by1", -1 );
+        API_SUFFIX(LAPACKE_xerbla)( "LAPACKE_zuncsd2by1", -1 );
         return -1;
     }
 #ifndef LAPACK_DISABLE_NAN_CHECK
-    /* Optionally check input matrices for NaNs */
-    nrows_x11 =  p ;
-    nrows_x21 =  m-p ;
-    if( LAPACKE_zge_nancheck( matrix_layout, nrows_x11, q, x11, ldx11 ) ) {
-        return -8;
+    if( LAPACKE_get_nancheck() ) {
+        /* Optionally check input matrices for NaNs */
+        nrows_x11 = p;
+        nrows_x21 = m-p;
+        if( API_SUFFIX(LAPACKE_zge_nancheck)( matrix_layout, nrows_x11, q, x11, ldx11 ) ) {
+            return -8;
+        }
+ 
+        if( API_SUFFIX(LAPACKE_zge_nancheck)( matrix_layout, nrows_x21, q, x21, ldx21 ) ) {
+            return -9;
+        }
     }
-
-    if( LAPACKE_zge_nancheck( matrix_layout, nrows_x21, q, x21, ldx21 ) ) {
-        return -9;
-    }
-
 #endif
     /* Allocate memory for working array(s) */
     iwork = (lapack_int*)LAPACKE_malloc( sizeof(lapack_int) * MAX(1,m-MIN(MIN(p,m-p),MIN(q,m-q))) );
@@ -74,7 +74,7 @@ lapack_int LAPACKE_zuncsd2by1( int matrix_layout, char jobu1, char jobu2,
         goto exit_level_0;
     }
     /* Query optimal working array(s) size */
-    info = LAPACKE_zuncsd2by1_work( matrix_layout, jobu1, jobu2, jobv1t, m, p, q, 
+    info = API_SUFFIX(LAPACKE_zuncsd2by1_work)( matrix_layout, jobu1, jobu2, jobv1t, m, p, q,
                                 x11, ldx11, x21, ldx21, theta, u1, ldu1, u2,
                                 ldu2, v1t, ldv1t, &work_query,
                                 lwork, &rwork_query, lrwork, iwork );
@@ -95,7 +95,7 @@ lapack_int LAPACKE_zuncsd2by1( int matrix_layout, char jobu1, char jobu2,
         goto exit_level_2;
     }
     /* Call middle-level interface */
-    info = LAPACKE_zuncsd2by1_work( matrix_layout, jobu1, jobu2, jobv1t, m, p, q, 
+    info = API_SUFFIX(LAPACKE_zuncsd2by1_work)( matrix_layout, jobu1, jobu2, jobv1t, m, p, q,
                                 x11, ldx11, x21, ldx21, theta, u1, ldu1, u2,
                                 ldu2, v1t, ldv1t, work, lwork, rwork, lrwork, iwork );
     /* Release memory and exit */
@@ -106,7 +106,7 @@ exit_level_1:
     LAPACKE_free( iwork );
 exit_level_0:
     if( info == LAPACK_WORK_MEMORY_ERROR ) {
-        LAPACKE_xerbla( "LAPACKE_zuncsd2by1", info );
+        API_SUFFIX(LAPACKE_xerbla)( "LAPACKE_zuncsd2by1", info );
     }
     return info;
 }
